[hornetq-commits] JBoss hornetq SVN: r8604 - in trunk/src/main/org/hornetq: core/client and 14 other directories.

do-not-reply at jboss.org do-not-reply at jboss.org
Mon Dec 7 07:33:08 EST 2009


Author: jmesnil
Date: 2009-12-07 07:33:07 -0500 (Mon, 07 Dec 2009)
New Revision: 8604

Modified:
   trunk/src/main/org/hornetq/core/asyncio/impl/AsynchronousFileImpl.java
   trunk/src/main/org/hornetq/core/client/ClientSession.java
   trunk/src/main/org/hornetq/core/client/impl/ClientConsumerImpl.java
   trunk/src/main/org/hornetq/core/config/impl/ConfigurationImpl.java
   trunk/src/main/org/hornetq/core/journal/impl/AbstractJournalUpdateTask.java
   trunk/src/main/org/hornetq/core/journal/impl/JournalCompactor.java
   trunk/src/main/org/hornetq/core/journal/impl/JournalImpl.java
   trunk/src/main/org/hornetq/core/journal/impl/JournalReaderCallback.java
   trunk/src/main/org/hornetq/core/journal/impl/JournalTransaction.java
   trunk/src/main/org/hornetq/core/journal/impl/TimedBuffer.java
   trunk/src/main/org/hornetq/core/journal/impl/dataformat/JournalAddRecord.java
   trunk/src/main/org/hornetq/core/journal/impl/dataformat/JournalAddRecordTX.java
   trunk/src/main/org/hornetq/core/journal/impl/dataformat/JournalDeleteRecord.java
   trunk/src/main/org/hornetq/core/journal/impl/dataformat/JournalDeleteRecordTX.java
   trunk/src/main/org/hornetq/core/message/impl/MessageImpl.java
   trunk/src/main/org/hornetq/core/paging/PagingManager.java
   trunk/src/main/org/hornetq/core/paging/PagingStore.java
   trunk/src/main/org/hornetq/core/paging/PagingStoreFactory.java
   trunk/src/main/org/hornetq/core/paging/impl/PagingStoreFactoryNIO.java
   trunk/src/main/org/hornetq/core/paging/impl/TestSupportPageStore.java
   trunk/src/main/org/hornetq/core/remoting/impl/wireformat/CreateSessionMessage.java
   trunk/src/main/org/hornetq/core/remoting/impl/wireformat/RollbackMessage.java
   trunk/src/main/org/hornetq/core/remoting/impl/wireformat/SessionReceiveContinuationMessage.java
   trunk/src/main/org/hornetq/core/remoting/impl/wireformat/SessionSendContinuationMessage.java
   trunk/src/main/org/hornetq/core/replication/ReplicationManager.java
   trunk/src/main/org/hornetq/core/replication/impl/ReplicatedJournal.java
   trunk/src/main/org/hornetq/core/replication/impl/ReplicationManagerImpl.java
   trunk/src/main/org/hornetq/core/server/impl/HornetQServerImpl.java
   trunk/src/main/org/hornetq/jms/server/JMSServerManager.java
   trunk/src/main/org/hornetq/ra/HornetQRAXAResource.java
   trunk/src/main/org/hornetq/utils/Base64.java
Log:
fixed javadoc warnings

Modified: trunk/src/main/org/hornetq/core/asyncio/impl/AsynchronousFileImpl.java
===================================================================
--- trunk/src/main/org/hornetq/core/asyncio/impl/AsynchronousFileImpl.java	2009-12-07 11:09:31 UTC (rev 8603)
+++ trunk/src/main/org/hornetq/core/asyncio/impl/AsynchronousFileImpl.java	2009-12-07 12:33:07 UTC (rev 8604)
@@ -397,9 +397,6 @@
     * This needs to be synchronized because of 
     * http://bugs.sun.com/view_bug.do?bug_id=6791815
     * http://mail.openjdk.java.net/pipermail/hotspot-runtime-dev/2009-January/000386.html
-    * 
-    * @param size
-    * @return
     */
    public synchronized static ByteBuffer newBuffer(final int size)
    {

Modified: trunk/src/main/org/hornetq/core/client/ClientSession.java
===================================================================
--- trunk/src/main/org/hornetq/core/client/ClientSession.java	2009-12-07 11:09:31 UTC (rev 8603)
+++ trunk/src/main/org/hornetq/core/client/ClientSession.java	2009-12-07 12:33:07 UTC (rev 8604)
@@ -15,7 +15,6 @@
 
 import javax.transaction.xa.XAResource;
 
-import org.hornetq.core.buffers.HornetQBuffer;
 import org.hornetq.core.exception.HornetQException;
 import org.hornetq.core.remoting.impl.wireformat.SessionBindingQueryResponseMessage;
 import org.hornetq.core.remoting.impl.wireformat.SessionQueueQueryResponseMessage;
@@ -26,6 +25,7 @@
  * @author <a href="mailto:clebert.suconic at jboss.org">Clebert Suconic</a>
  * @author <a href="mailto:ataylor at redhat.com">Andy Taylor</a>
  * @author <a href="jmesnil at redhat.com">Jeff Mesnil</a>
+ * 
  */
 public interface ClientSession extends XAResource
 {
@@ -159,7 +159,7 @@
     * 
     * @param address the queue will be bound to this address
     * @param queueName the name of the queue
-    * @param filterString only messages which match this filter will be put in the queue
+    * @param filter only messages which match this filter will be put in the queue
     * @throws HornetQException in an exception occurs while creating the queue
     */
    void createTemporaryQueue(SimpleString address, SimpleString queueName, SimpleString filter) throws HornetQException;
@@ -169,7 +169,7 @@
     * 
     * @param address the queue will be bound to this address
     * @param queueName the name of the queue
-    * @param filterString only messages which match this filter will be put in the queue
+    * @param filter only messages which match this filter will be put in the queue
     * @throws HornetQException in an exception occurs while creating the queue
     */
    void createTemporaryQueue(String address, String queueName, String filter) throws HornetQException;
@@ -218,7 +218,7 @@
     * @return a ClientConsumer
     * @throws HornetQException if an exception occurs while creating the ClientConsumer
     */
-   ClientConsumer createConsumer(SimpleString queueName, SimpleString filterString) throws HornetQException;
+   ClientConsumer createConsumer(SimpleString queueName, SimpleString filter) throws HornetQException;
 
    /**
     * Create a ClientConsumer to consume messages matching the filter from the queue with the given name.
@@ -228,7 +228,7 @@
     * @return a ClientConsumer
     * @throws HornetQException if an exception occurs while creating the ClientConsumer
     */
-   ClientConsumer createConsumer(String queueName, String filterString) throws HornetQException;
+   ClientConsumer createConsumer(String queueName, String filter) throws HornetQException;
 
    /**
     * Create a ClientConsumer to consume or browse messages from the queue with the given name.
@@ -286,7 +286,7 @@
     * @return a ClientConsumer
     * @throws HornetQException if an exception occurs while creating the ClientConsumer
     */
-   ClientConsumer createConsumer(SimpleString queueName, SimpleString filterString, boolean browseOnly) throws HornetQException;
+   ClientConsumer createConsumer(SimpleString queueName, SimpleString filter, boolean browseOnly) throws HornetQException;
 
    /**
     * Create a ClientConsumer to consume or browse messages matching the filter from the queue with the given name.

Modified: trunk/src/main/org/hornetq/core/client/impl/ClientConsumerImpl.java
===================================================================
--- trunk/src/main/org/hornetq/core/client/impl/ClientConsumerImpl.java	2009-12-07 11:09:31 UTC (rev 8603)
+++ trunk/src/main/org/hornetq/core/client/impl/ClientConsumerImpl.java	2009-12-07 12:33:07 UTC (rev 8604)
@@ -578,8 +578,8 @@
     * LargeMessageBuffer will call flowcontrol here, while other handleMessage will also be calling flowControl.
     * So, this operation needs to be atomic.
     * 
-    * @parameter discountSlowConsumer When dealing with slowConsumers, we need to discount one credit that was pre-sent when the first receive was called. For largeMessage that is only done at the latest packet
-    * */
+    * @param discountSlowConsumer When dealing with slowConsumers, we need to discount one credit that was pre-sent when the first receive was called. For largeMessage that is only done at the latest packet
+    */
    public void flowControl(final int messageBytes, final boolean discountSlowConsumer) throws HornetQException
    {   
       if (clientWindowSize >= 0)

Modified: trunk/src/main/org/hornetq/core/config/impl/ConfigurationImpl.java
===================================================================
--- trunk/src/main/org/hornetq/core/config/impl/ConfigurationImpl.java	2009-12-07 11:09:31 UTC (rev 8603)
+++ trunk/src/main/org/hornetq/core/config/impl/ConfigurationImpl.java	2009-12-07 12:33:07 UTC (rev 8604)
@@ -387,9 +387,6 @@
       return persistDeliveryCountBeforeDelivery;
    }
 
-   /**
-    * @param strictJMS the strictJMS to set
-    */
    public void setPersistDeliveryCountBeforeDelivery(final boolean persistDeliveryCountBeforeDelivery)
    {
       this.persistDeliveryCountBeforeDelivery = persistDeliveryCountBeforeDelivery;

Modified: trunk/src/main/org/hornetq/core/journal/impl/AbstractJournalUpdateTask.java
===================================================================
--- trunk/src/main/org/hornetq/core/journal/impl/AbstractJournalUpdateTask.java	2009-12-07 11:09:31 UTC (rev 8603)
+++ trunk/src/main/org/hornetq/core/journal/impl/AbstractJournalUpdateTask.java	2009-12-07 12:33:07 UTC (rev 8604)
@@ -83,11 +83,6 @@
 
    // Public --------------------------------------------------------
    
-   /**
-    * @param tmpRenameFile
-    * @param files
-    * @param newFiles
-    */
    public static SequentialFile writeControlFile(final SequentialFileFactory fileFactory,
                                                  final List<JournalFile> files,
                                                  final List<JournalFile> newFiles,

Modified: trunk/src/main/org/hornetq/core/journal/impl/JournalCompactor.java
===================================================================
--- trunk/src/main/org/hornetq/core/journal/impl/JournalCompactor.java	2009-12-07 11:09:31 UTC (rev 8603)
+++ trunk/src/main/org/hornetq/core/journal/impl/JournalCompactor.java	2009-12-07 12:33:07 UTC (rev 8604)
@@ -152,10 +152,6 @@
       pendingTransactions.put(transactionID, new PendingTransaction(ids));
    }
 
-   /**
-    * @param id
-    * @param journalTransaction
-    */
    public void addCommandCommit(final JournalTransaction liveTransaction, final JournalFile currentFile)
    {
       pendingCommands.add(new CommitCompactCommand(liveTransaction, currentFile));

Modified: trunk/src/main/org/hornetq/core/journal/impl/JournalImpl.java
===================================================================
--- trunk/src/main/org/hornetq/core/journal/impl/JournalImpl.java	2009-12-07 11:09:31 UTC (rev 8603)
+++ trunk/src/main/org/hornetq/core/journal/impl/JournalImpl.java	2009-12-07 12:33:07 UTC (rev 8604)
@@ -1104,10 +1104,10 @@
     * 
     * <p> transactionData allows you to store any other supporting user-data related to the transaction</p>
     * 
-    * <p> This method also uses the same logic applied on {@link JournalImpl#appendCommitRecord(long)}
+    * <p> This method also uses the same logic applied on {@link JournalImpl#appendCommitRecord(long, boolean)}
     * 
     * @param txID
-    * @param transactionData - extra user data for the prepare
+    * @param transactionData extra user data for the prepare
     * @throws Exception
     */
    public void appendPrepareRecord(final long txID,
@@ -1185,7 +1185,6 @@
     * <p> We can't just use a global counter as reclaiming could delete files after the transaction was successfully committed. 
     *     That also means not having a whole file on journal-reload doesn't mean we have to invalidate the transaction </p>
     *
-    * @see JournalImpl#writeTransaction(byte, long, org.hornetq.core.journal.impl.JournalImpl.JournalTransaction, EncodingSupport)
     */
 
    public void appendCommitRecord(final long txID, final boolean sync, final IOCompletion callback) throws Exception

Modified: trunk/src/main/org/hornetq/core/journal/impl/JournalReaderCallback.java
===================================================================
--- trunk/src/main/org/hornetq/core/journal/impl/JournalReaderCallback.java	2009-12-07 11:09:31 UTC (rev 8603)
+++ trunk/src/main/org/hornetq/core/journal/impl/JournalReaderCallback.java	2009-12-07 12:33:07 UTC (rev 8604)
@@ -61,13 +61,13 @@
    /**
     * @param transactionID
     * @param extraData
-    * @param summaryData
+    * @param numberOfRecords
     */
    void onReadPrepareRecord(long transactionID, byte[] extraData, int numberOfRecords) throws Exception;
 
    /**
     * @param transactionID
-    * @param summaryData
+    * @param numberOfRecords
     */
    void onReadCommitRecord(long transactionID, int numberOfRecords) throws Exception;
 

Modified: trunk/src/main/org/hornetq/core/journal/impl/JournalTransaction.java
===================================================================
--- trunk/src/main/org/hornetq/core/journal/impl/JournalTransaction.java	2009-12-07 11:09:31 UTC (rev 8603)
+++ trunk/src/main/org/hornetq/core/journal/impl/JournalTransaction.java	2009-12-07 12:33:07 UTC (rev 8604)
@@ -183,7 +183,7 @@
 
    /**
     * @param currentFile
-    * @param bb
+    * @param data
     */
    public void fillNumberOfRecords(final JournalFile currentFile, final JournalInternalRecord data)
    {
@@ -222,9 +222,6 @@
       }
    }
 
-   /**
-    * @return
-    */
    public TransactionCallback getCallback(final JournalFile file) throws Exception
    {
       if (callbackList == null)

Modified: trunk/src/main/org/hornetq/core/journal/impl/TimedBuffer.java
===================================================================
--- trunk/src/main/org/hornetq/core/journal/impl/TimedBuffer.java	2009-12-07 11:09:31 UTC (rev 8603)
+++ trunk/src/main/org/hornetq/core/journal/impl/TimedBuffer.java	2009-12-07 12:33:07 UTC (rev 8604)
@@ -188,7 +188,6 @@
    /**
     * Verify if the size fits the buffer
     * @param sizeChecked
-    * @return
     */
    public synchronized boolean checkSize(final int sizeChecked)
    {

Modified: trunk/src/main/org/hornetq/core/journal/impl/dataformat/JournalAddRecord.java
===================================================================
--- trunk/src/main/org/hornetq/core/journal/impl/dataformat/JournalAddRecord.java	2009-12-07 11:09:31 UTC (rev 8603)
+++ trunk/src/main/org/hornetq/core/journal/impl/dataformat/JournalAddRecord.java	2009-12-07 12:33:07 UTC (rev 8604)
@@ -39,7 +39,6 @@
     * @param id
     * @param recordType
     * @param record
-    * @param size
     */
    public JournalAddRecord(final boolean add, final long id, final byte recordType, final EncodingSupport record)
    {

Modified: trunk/src/main/org/hornetq/core/journal/impl/dataformat/JournalAddRecordTX.java
===================================================================
--- trunk/src/main/org/hornetq/core/journal/impl/dataformat/JournalAddRecordTX.java	2009-12-07 11:09:31 UTC (rev 8603)
+++ trunk/src/main/org/hornetq/core/journal/impl/dataformat/JournalAddRecordTX.java	2009-12-07 12:33:07 UTC (rev 8604)
@@ -41,7 +41,6 @@
     * @param id
     * @param recordType
     * @param record
-    * @param size
     */
    public JournalAddRecordTX(final boolean add,
                              final long txID,

Modified: trunk/src/main/org/hornetq/core/journal/impl/dataformat/JournalDeleteRecord.java
===================================================================
--- trunk/src/main/org/hornetq/core/journal/impl/dataformat/JournalDeleteRecord.java	2009-12-07 11:09:31 UTC (rev 8603)
+++ trunk/src/main/org/hornetq/core/journal/impl/dataformat/JournalDeleteRecord.java	2009-12-07 12:33:07 UTC (rev 8604)
@@ -30,9 +30,6 @@
 
    /**
     * @param id
-    * @param recordType
-    * @param record
-    * @param size
     */
    public JournalDeleteRecord(final long id)
    {

Modified: trunk/src/main/org/hornetq/core/journal/impl/dataformat/JournalDeleteRecordTX.java
===================================================================
--- trunk/src/main/org/hornetq/core/journal/impl/dataformat/JournalDeleteRecordTX.java	2009-12-07 11:09:31 UTC (rev 8603)
+++ trunk/src/main/org/hornetq/core/journal/impl/dataformat/JournalDeleteRecordTX.java	2009-12-07 12:33:07 UTC (rev 8604)
@@ -34,10 +34,9 @@
    private final EncodingSupport record;
 
    /**
+    * @param txID
     * @param id
-    * @param recordType
     * @param record
-    * @param size
     */
    public JournalDeleteRecordTX(final long txID, final long id, final EncodingSupport record)
    {

Modified: trunk/src/main/org/hornetq/core/message/impl/MessageImpl.java
===================================================================
--- trunk/src/main/org/hornetq/core/message/impl/MessageImpl.java	2009-12-07 11:09:31 UTC (rev 8603)
+++ trunk/src/main/org/hornetq/core/message/impl/MessageImpl.java	2009-12-07 12:33:07 UTC (rev 8604)
@@ -122,7 +122,7 @@
     * @param expiration
     * @param timestamp
     * @param priority
-    * @param body
+    * @param initialMessageBufferSize
     */
    protected MessageImpl(final byte type,
                          final boolean durable,

Modified: trunk/src/main/org/hornetq/core/paging/PagingManager.java
===================================================================
--- trunk/src/main/org/hornetq/core/paging/PagingManager.java	2009-12-07 11:09:31 UTC (rev 8603)
+++ trunk/src/main/org/hornetq/core/paging/PagingManager.java	2009-12-07 12:33:07 UTC (rev 8604)
@@ -68,14 +68,10 @@
     */
    void removeTransaction(long transactionID);
 
-   /**
-    * @return
-    */
    long getTotalMemory();
 
    /**
     * @param size
-    * @return
     */
    long addSize(long size);
 

Modified: trunk/src/main/org/hornetq/core/paging/PagingStore.java
===================================================================
--- trunk/src/main/org/hornetq/core/paging/PagingStore.java	2009-12-07 11:09:31 UTC (rev 8603)
+++ trunk/src/main/org/hornetq/core/paging/PagingStore.java	2009-12-07 12:33:07 UTC (rev 8604)
@@ -56,42 +56,18 @@
    Page createPage(final int page) throws Exception;
 
    /**
-    * 
     * @return false if a thread was already started, or if not in page mode
     * @throws Exception 
     */
    boolean startDepaging();
 
-   /**
-    * 
-    * @param message
-    * @throws Exception
-    */
    void addSize(ServerMessage message, boolean add);
    
-   /**
-    * 
-    * @param reference
-    * @throws Exception
-    */
    void addSize(MessageReference reference, boolean add);
    
-   /**
-    * 
-    * @param desired
-    * @return
-    */
    int getAvailableProducerCredits(int desired);
    
-   /**
-    * 
-    * @param credits
-    */
    void returnProducerCredits(int credits);
    
-   /**
-    * 
-    * @return
-    */
    ServerProducerCreditManager getProducerCreditManager();
 }

Modified: trunk/src/main/org/hornetq/core/paging/PagingStoreFactory.java
===================================================================
--- trunk/src/main/org/hornetq/core/paging/PagingStoreFactory.java	2009-12-07 11:09:31 UTC (rev 8603)
+++ trunk/src/main/org/hornetq/core/paging/PagingStoreFactory.java	2009-12-07 12:33:07 UTC (rev 8604)
@@ -42,10 +42,6 @@
 
    List<PagingStore> reloadStores(HierarchicalRepository<AddressSettings> addressSettingsRepository) throws Exception;
 
-   /**
-    * @param storeName
-    * @return
-    */
    SequentialFileFactory newFileFactory(SimpleString destinationName) throws Exception;
 
 }

Modified: trunk/src/main/org/hornetq/core/paging/impl/PagingStoreFactoryNIO.java
===================================================================
--- trunk/src/main/org/hornetq/core/paging/impl/PagingStoreFactoryNIO.java	2009-12-07 11:09:31 UTC (rev 8603)
+++ trunk/src/main/org/hornetq/core/paging/impl/PagingStoreFactoryNIO.java	2009-12-07 12:33:07 UTC (rev 8604)
@@ -101,10 +101,6 @@
                                  syncNonTransactional);
    }
 
-   /**
-    * @param storeName
-    * @return
-    */
    public synchronized SequentialFileFactory newFileFactory(final SimpleString destinationName) throws Exception
    {
 

Modified: trunk/src/main/org/hornetq/core/paging/impl/TestSupportPageStore.java
===================================================================
--- trunk/src/main/org/hornetq/core/paging/impl/TestSupportPageStore.java	2009-12-07 11:09:31 UTC (rev 8603)
+++ trunk/src/main/org/hornetq/core/paging/impl/TestSupportPageStore.java	2009-12-07 12:33:07 UTC (rev 8604)
@@ -27,7 +27,7 @@
     * Remove the first page from the Writing Queue.
     * The file will still exist until Page.delete is called, 
     * So, case the system is reloaded the same Page will be loaded back if delete is not called.
-    * @return
+    *
     * @throws Exception
     * 
     * Note: This should still be part of the interface, even though HornetQ only uses through the 

Modified: trunk/src/main/org/hornetq/core/remoting/impl/wireformat/CreateSessionMessage.java
===================================================================
--- trunk/src/main/org/hornetq/core/remoting/impl/wireformat/CreateSessionMessage.java	2009-12-07 11:09:31 UTC (rev 8603)
+++ trunk/src/main/org/hornetq/core/remoting/impl/wireformat/CreateSessionMessage.java	2009-12-07 12:33:07 UTC (rev 8604)
@@ -208,9 +208,6 @@
       return false;
    }
 
-   /**
-    * @return
-    */
    public int getMinLargeMessageSize()
    {
       return minLargeMessageSize;

Modified: trunk/src/main/org/hornetq/core/remoting/impl/wireformat/RollbackMessage.java
===================================================================
--- trunk/src/main/org/hornetq/core/remoting/impl/wireformat/SessionReceiveContinuationMessage.java	2009-12-07 11:09:31 UTC (rev 8603)
+++ trunk/src/main/org/hornetq/core/remoting/impl/wireformat/SessionReceiveContinuationMessage.java	2009-12-07 12:33:07 UTC (rev 8604)
@@ -40,16 +40,13 @@
 
    // Constructors --------------------------------------------------
 
-   /**
-    * @param type
-    */
    public SessionReceiveContinuationMessage()
    {
       super(SESS_RECEIVE_CONTINUATION);
    }
 
    /**
-    * @param type
+    * @param consumerID
     * @param body
     * @param continues
     * @param requiresResponse

Modified: trunk/src/main/org/hornetq/core/remoting/impl/wireformat/SessionSendContinuationMessage.java
===================================================================
--- trunk/src/main/org/hornetq/core/remoting/impl/wireformat/SessionSendContinuationMessage.java	2009-12-07 11:09:31 UTC (rev 8603)
+++ trunk/src/main/org/hornetq/core/remoting/impl/wireformat/SessionSendContinuationMessage.java	2009-12-07 12:33:07 UTC (rev 8604)
@@ -39,16 +39,12 @@
 
    // Constructors --------------------------------------------------
 
-   /**
-    * @param type
-    */
    public SessionSendContinuationMessage()
    {
       super(SESS_SEND_CONTINUATION);
    }
 
    /**
-    * @param type
     * @param body
     * @param continues
     * @param requiresResponse

Modified: trunk/src/main/org/hornetq/core/replication/ReplicationManager.java
===================================================================
--- trunk/src/main/org/hornetq/core/replication/ReplicationManager.java	2009-12-07 11:09:31 UTC (rev 8603)
+++ trunk/src/main/org/hornetq/core/replication/ReplicationManager.java	2009-12-07 12:33:07 UTC (rev 8604)
@@ -67,7 +67,7 @@
 
 
    /**
-    * @param storeName
+    * @param message
     * @param pageNumber
     */
    void pageWrite(PagedMessage message, int pageNumber);

Modified: trunk/src/main/org/hornetq/core/replication/impl/ReplicatedJournal.java
===================================================================
--- trunk/src/main/org/hornetq/core/replication/impl/ReplicatedJournal.java	2009-12-07 11:09:31 UTC (rev 8603)
+++ trunk/src/main/org/hornetq/core/replication/impl/ReplicatedJournal.java	2009-12-07 12:33:07 UTC (rev 8604)
@@ -437,7 +437,7 @@
     * @param committedRecords
     * @param preparedTransactions
     * @param transactionFailure
-    * @return
+    *
     * @throws Exception
     * @see org.hornetq.core.journal.Journal#load(java.util.List, java.util.List, org.hornetq.core.journal.TransactionFailureCallback)
     */
@@ -450,7 +450,7 @@
 
    /**
     * @param reloadManager
-    * @return
+    *
     * @throws Exception
     * @see org.hornetq.core.journal.Journal#load(org.hornetq.core.journal.LoaderCallback)
     */

Modified: trunk/src/main/org/hornetq/core/replication/impl/ReplicationManagerImpl.java
===================================================================
--- trunk/src/main/org/hornetq/core/replication/impl/ReplicationManagerImpl.java	2009-12-07 11:09:31 UTC (rev 8603)
+++ trunk/src/main/org/hornetq/core/replication/impl/ReplicationManagerImpl.java	2009-12-07 12:33:07 UTC (rev 8604)
@@ -89,9 +89,6 @@
 
    // Constructors --------------------------------------------------
 
-   /**
-    * @param replicationConnectionManager
-    */
    public ReplicationManagerImpl(final FailoverManager failoverManager, final ExecutorFactory executorFactory)
    {
       super();

Modified: trunk/src/main/org/hornetq/core/server/impl/HornetQServerImpl.java
===================================================================
--- trunk/src/main/org/hornetq/core/server/impl/HornetQServerImpl.java	2009-12-07 11:09:31 UTC (rev 8603)
+++ trunk/src/main/org/hornetq/core/server/impl/HornetQServerImpl.java	2009-12-07 12:33:07 UTC (rev 8604)
@@ -907,7 +907,6 @@
 
    /** 
     * This method is protected as it may be used as a hook for creating a custom storage manager (on tests for instance) 
-    * @return
     */
    protected StorageManager createStorageManager()
    {

Modified: trunk/src/main/org/hornetq/jms/server/JMSServerManager.java
===================================================================
--- trunk/src/main/org/hornetq/jms/server/JMSServerManager.java	2009-12-07 11:09:31 UTC (rev 8603)
+++ trunk/src/main/org/hornetq/jms/server/JMSServerManager.java	2009-12-07 12:33:07 UTC (rev 8604)
@@ -226,8 +226,5 @@
 
    void setContext(final Context context);
 
-   /**
-    * @return
-    */
    HornetQServer getHornetQServer();
 }

Modified: trunk/src/main/org/hornetq/ra/HornetQRAXAResource.java
===================================================================
--- trunk/src/main/org/hornetq/ra/HornetQRAXAResource.java	2009-12-07 11:09:31 UTC (rev 8603)
+++ trunk/src/main/org/hornetq/ra/HornetQRAXAResource.java	2009-12-07 12:33:07 UTC (rev 8604)
@@ -192,7 +192,7 @@
 
    /**
     * Recover 
-    * @param flags One of TMSTARTRSCAN, TMENDRSCAN, TMNOFLAGS
+    * @param flag One of TMSTARTRSCAN, TMENDRSCAN, TMNOFLAGS
     * @return Zero or more XIDs
     * @exception XAException An error has occurred
     */

Modified: trunk/src/main/org/hornetq/utils/Base64.java
===================================================================
--- trunk/src/main/org/hornetq/utils/Base64.java	2009-12-07 11:09:31 UTC (rev 8603)
+++ trunk/src/main/org/hornetq/utils/Base64.java	2009-12-07 12:33:07 UTC (rev 8604)
@@ -688,8 +688,7 @@
      * @param source The data to convert
      * @param off Offset in array where conversion should begin
      * @param len Length of data to convert
-     * @param options Specified options
-    * @param options alphabet type is pulled from this (standard, url-safe, ordered)
+     * @param options options alphabet type is pulled from this (standard, url-safe, ordered)
      * @see Base64#GZIP
      * @see Base64#DONT_BREAK_LINES
      * @since 2.0



More information about the hornetq-commits mailing list
--- trunk/src/main/org/hornetq/core/remoting/impl/wireformat/RollbackMessage.java	2009-12-07 11:09:31 UTC (rev 8603)
+++ trunk/src/main/org/hornetq/core/remoting/impl/wireformat/RollbackMessage.java	2009-12-07 12:33:07 UTC (rev 8604)
@@ -28,9 +28,6 @@
 public class RollbackMessage extends PacketImpl
 {
 
-   /**
-    * @param type
-    */
    public RollbackMessage()
    {
       super(SESS_ROLLBACK);
@@ -58,11 +55,11 @@
    }
 
    /**
     * @param considerLastMessageAsDelivered the considerLastMessageAsDelivered to set
     */
-   public void setConsiderLastMessageAsDelivered(final boolean isLastMessageAsDelived)
+   public void setConsiderLastMessageAsDelivered(final boolean isLastMessageAsDelivered)
    {
-      considerLastMessageAsDelivered = isLastMessageAsDelived;
+      considerLastMessageAsDelivered = isLastMessageAsDelivered;
    }
 
    @Override
@@ -58,11 +55,11 @@
 
    /**
-    * @param considerLastMessageAsDelivered the considerLastMessageAsDelivered to set
+    * @param isLastMessageAsDelivered the considerLastMessageAsDelivered to set
     */

Modified: trunk/src/main/org/hornetq/core/remoting/impl/wireformat/SessionReceiveContinuationMessage.java
===================================================================